import pandas as pd
import numpy as np

# Load the data
data = pd.read_csv("/home/jvaldes/Desktop/krishna-thesis/thesiscodeimplementation/clustering_results.csv")

# Define the weights for each validation index
weights = {
    "Silhouette Score": 0.3,
    "Davies-Bouldin Score": -0.3,  # Minimize, hence negative weight
    "Calinski-Harabasz Score": 0.2,
    "Dunn Index": 0.1,
    "COP Index": -0.1,  # Minimize, hence negative weight
}

# Normalize the scores to bring them to the same scale
def normalize(series):
    return (series - series.min()) / (series.max() - series.min())

for col in weights.keys():
    if col in data.columns:
        data[f"normalized_{col}"] = normalize(data[col])

# Calculate a composite score
data["Composite Score"] = sum(
    weights[col] * data[f"normalized_{col}"] for col in weights.keys()
    if f"normalized_{col}" in data.columns
)

# Identify the best parameter combination
best_parameters = data.loc[data["Composite Score"].idxmax()]

# Display the best parameters
print("Best Parameter Combination:")
print(best_parameters)

# Save the results to a file
data.to_csv("results_with_composite_score.csv", index=False)
